@@ -122,7 +122,12 @@ class Bridge extends Extension {
                 payload = {
                     friendly_name: resolvedEntity.settings.friendlyName, ieee_address: ieeeAddress,
                 };
-            } else payload = {ieee_address: ieeeAddress}; // deviceLeave
+            } else {
+                // deviceLeave
+                const settingsDevice = settings.getDevice(ieeeAddress);
+                payload = {ieee_address: ieeeAddress,
+                    friendly_name: settingsDevice ? settingsDevice.friendlyName : null};
+            }
 
             await this.mqtt.publish(
                 'bridge/event',
